==> GeneticsBase_1.0.0.tar.gz: GeneticsBase/R/LDband.R <==
"LDband.geneSet" <- function( object, width=31 )
  {
    if(!odd(width)) stop("`width' must be odd.") 
    lag <- floor(width/2)

    myrownames <- object@markerInfo$Name
    mycolnames <- c(
                     paste("marker",lag:1,sep="-"),
                     "marker",
                     paste("marker",1:lag,sep="+")
                     )

    ped<-geneSet2Ped2(object)

    tmp<-getLDband(ped$ped,ped$columns, width, pooling.threshold=0.1, 
                   iprint=FALSE)
    D<-tmp$DMat
    rownames(D) <- myrownames 
    colnames(D) <- mycolnames

    Dprime<-tmp$DprimeMat
    rownames(Dprime) <-  myrownames
    colnames(Dprime) <- mycolnames

    corr<-tmp$rMat
    rownames(corr) <- myrownames
    colnames(corr) <- mycolnames

    r.2<-tmp$r2Mat
    rownames(r.2) <- myrownames
    colnames(r.2) <- mycolnames

    chisq<-tmp$chisqMat
    rownames(chisq) <- myrownames
    colnames(chisq) <- mycolnames

    p.value<-tmp$pvalMat
    rownames(p.value) <- myrownames
    colnames(p.value) <- mycolnames

    nobs<-tmp$nMat
    rownames(nobs) <- myrownames
    colnames(nobs) <- mycolnames

    LOD<-tmp$LODMat
    rownames(LOD) <- myrownames
    colnames(LOD) <- mycolnames

    retval <- new("LDband",
                   call=match.call(),
                   "D"=D,
                   "D'"=Dprime,
                   "r" = corr,
                   "R^2" = r.2,
                   "n"=nobs,
                   "X^2"=chisq,
                   "P-value"=p.value,
                   "LOD"=LOD
           )
    retval
  }

setGeneric("LDband", function(object, width=31,...)
           standardGeneric("LDband"))

setMethod("LDband", "geneSet", LDband.geneSet)

==> GeneticsBase_1.14.0.tar.gz: GeneticsBase/R/LDband.R <==
"LDband.geneSet" <- function( object, width=31, pooling.threshold=0.1, founderOnly=FALSE, quiet=TRUE )
  {
    if(!odd(width)) stop("`width' must be odd.") 
    lag <- floor(width/2)

    myrownames <- object@markerInfo$Name
    mycolnames <- c(
                     paste("marker",lag:1,sep="-"),
                     "marker",
                     paste("marker",1:lag,sep="+")
                     )

    tmp<-getLDband(object, width, pooling.threshold, founderOnly, quiet)
    D<-tmp$DMat
    rownames(D) <- myrownames 
    colnames(D) <- mycolnames

    Dprime<-tmp$DprimeMat
    rownames(Dprime) <-  myrownames
    colnames(Dprime) <- mycolnames

    corr<-tmp$rMat
    rownames(corr) <- myrownames
    colnames(corr) <- mycolnames

    r.2<-tmp$r2Mat
    rownames(r.2) <- myrownames
    colnames(r.2) <- mycolnames

    chisq<-tmp$chisqMat
    rownames(chisq) <- myrownames
    colnames(chisq) <- mycolnames

    p.value<-tmp$pvalMat
    rownames(p.value) <- myrownames
    colnames(p.value) <- mycolnames

    nobs<-tmp$nMat
    rownames(nobs) <- myrownames
    colnames(nobs) <- mycolnames

    LOD<-tmp$LODMat
    rownames(LOD) <- myrownames
    colnames(LOD) <- mycolnames

    retval <- new("LDband",
                   call=match.call(),
                   "D"=D,
                   "D'"=Dprime,
                   "r" = corr,
                   "R^2" = r.2,
                   "n"=nobs,
                   "X^2"=chisq,
                   "P-value"=p.value,
                   "LOD"=LOD
           )
    retval
  }

setGeneric("LDband", function(object, width=31, pooling.threshold=0.1, founderOnly=FALSE, quiet=TRUE)
           standardGeneric("LDband"))

setMethod("LDband", "geneSet", LDband.geneSet)
